# NATools - Package with parallel corpora tools
# Copyright (C) 2002-2004  Alberto Simes
#
# This package is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.

package NAT::Config;

use 5.006;
use strict;
use warnings;

sub new {
  my $class = shift;
  my $self = {};
  if ($_[0]) {
    my $file = shift;
    open I, "$file" or die "Can't open file '$file'\n";
    while(<I>) {
      chomp;
      next if m!^\s*$!;
      next if m!^\s*#!;
      next if m!^\[!;
      my ($l,$r) = m!^([^=]+?)\s*=\s*(.*?)\s*$!;
      $self->{$l} = $r;
    }
    close I;
  }
  return bless $self, $class # amen
}

sub param {
  my $self = shift;
  my $val;
  my $param = shift;
  if (defined($_[0])) {
    $val = shift;
    $self->{$param} = $val;
  } else {
    $val = exists($self->{$param})?$self->{$param}:undef;
  }
  return $val;
}

sub write {
  my $self = shift;
  my $filename = shift;

  open O, ">$filename" or die "Can't open file '$filename'\n";
  print O "[nat]\n";
  for (keys %$self) {
    print O "$_=$self->{$_}\n";
  }
  close O;
}

1;
__END__

=head1 NAME

NAT::Config - Simple configuration file API

=head1 SYNOPSIS

  use NAT::Config;

=head1 AUTHOR

Alberto Manuel Brandao Simoes, E<lt>albie@alfarrabio.di.uminho.ptE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2002-2005 by Natura Project
http://natura.di.uminho.pt

This library is free software; you can redistribute it and/or modify
it under the GNU General Public License 2, which you should find on
parent directory. Distribution of this module should be done including
all NATools package, with respective copyright notice.

=cut
